@@ -101,6 +101,17 @@ def dialog( toplevel_window, title, question, description ):
     """ Present the user with a yes/no/cancel dialog 
         Reponse: Yes = True, No = False, Cancel = None """
 
+    if util.platform == util.MAEMO:
+        # Maemo 5 confirmation dialog style
+        dlg = hildon.hildon_note_new_confirmation(toplevel_window, \
+                '\n\n'.join([question, description]))
+        response = dlg.run()
+        dlg.destroy()
+        if response == gtk.RESPONSE_OK:
+            return True
+        else:
+            return False
+
     dlg = gtk.MessageDialog( toplevel_window, gtk.DIALOG_MODAL,
         gtk.MESSAGE_QUESTION )
     dlg.set_title(title)
