@@ -24,7 +24,7 @@ from simplegconf import gconf
 
 default_settings = {
     'db_location'       : '~/.panucci.sqlite',
-    'last_folder'       : '~',
+    'last_folder'       : '/home/user/MyDocs',
     'max_recent_files'  : 10,
     'progress_locked'   : False,
     'temp_playlist'     : '~/.panucci.m3u',
